<?php

declare(strict_types=1);

namespace Dedi\SyliusContactPlugin\Form;

use Dedi\SyliusContactPlugin\Model\AnswerModel;
use SM\Factory\Factory as StateMachineFactory;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\TextareaType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Validator\Constraints\NotNull;

final class AnswerType extends AbstractType
{
    private readonly StateMachineFactory $stateMachineFactory;

    public function __construct(
        StateMachineFactory $stateMachineFactory,
    ) {
        $this->stateMachineFactory = $stateMachineFactory;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('message', TextareaType::class, [
                'label' => 'dedi_sylius_contact_form.ui.form.message',
                'constraints' => [
                    new NotNull(),
                ],
            ])
            ->add('attachments', AttachmentCollectionType::class)
        ;

        /** @var AnswerModel $answerModel */
        $answerModel = $builder->getData();

        $stateMachine = $this->stateMachineFactory->get($answerModel->contactFormMessage, 'dedi_sylius_contact_form_message');

        if ($stateMachine->can('process')) {
            $builder
                ->add('process', CheckboxType::class, [
                    'label' => 'dedi_sylius_contact_form.ui.form.mark_as_process',
                    'required' => false,
                ])
            ;
        }
    }
}
